@@ -13,7 +13,7 @@ async fn add_one_job() -> Result<(), Box<dyn std::error::Error + 'static>>
     let mut sched = jact::JobScheduler::create();
 
     sched.add(jact::Job::new_one_shot(SDuration::from_secs(2), |_, _| Box::pin(async move {
-        eprintln!("Did this work? lol"); }))?).await.unwrap();
+        eprintln!("Did this work? lol"); Ok(()) }))?).await.unwrap();
 
     eprintln!("Past adding to sched!");
 
